@@ -186,7 +186,7 @@ SEXP OSR_is_projected(SEXP inSRID) {
 }
 
 
-SEXP R_GDAL_OSR_PROJ() {
+SEXP R_GDAL_OSR_PROJ(void) {
 
 #if ((GDAL_VERSION_MAJOR == 3 && GDAL_VERSION_MINOR == 0 && GDAL_VERSION_REV >= 1) || (GDAL_VERSION_MAJOR == 3 && GDAL_VERSION_MINOR > 0) || (GDAL_VERSION_MAJOR > 3))
         SEXP OSRProjVersion;
